/**
 * @fileOverview Sample for writing 'all' events to the event log
 * @name index.js
 * @author Cor Kalis <c.kalis@intoaccess.com>
 * @license UNLICENSED
 */
"use strict";

const async = require('async');
const http = require('http');

const PROTO = 'http:';
const PORT = 8088;
const PATH = '/AddEventRecord';
const HOST = '192.168.1.55';
const USER = 'RestUser';
const PWD = 'RestPassword';

// All currently known event numbers
const EVENT_NRS = [1, 2, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 15, 16, 17, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 52, 54, 55, 60, 61, 62, 63, 65, 67, 68, 70, 75, 76, 80, 83, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 110, 111, 112, 120, 121, 122, 132, 134, 135, 137, 138, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 300, 301, 302, 500, 501, 502, 503, 504, 510, 511, 512, 513, 514, 515, 516, 517, 518, 519, 520, 521, 550, 551, 552, 553, 554, 555, 556, 557, 558, 559, 560, 561, 568, 569, 570, 571, 572, 573, 574, 575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 590, 591, 600, 700, 701, 702, 703, 704, 705, 706, 707, 708, 709, 710, 711, 720, 721, 722, 723, 724, 725, 726, 727, 728, 750];


/**
 * Send an AddEventRecord call
 * @param {object} obj Object containing event data
 * @param {function} callback Called when done
 */
function sendEvent(obj, callback) {

  const strObj = JSON.stringify(obj);
  const bufObj = Buffer.from(strObj, 'utf-8');

  const req = http.request(
    {
      protocol: PROTO,
      hostname: HOST,
      port: PORT,
      path: PATH,
      method: 'POST',
      headers: {
        'Content-Type': 'application/json charset=utf-8',
        'Content-Length': Buffer.byteLength(bufObj)
      },
      auth: USER + ":" + PWD
    },
    (res) => {
      let reply = '';

      res.on('data', (chunk) => {
        reply += chunk;
      });

      res.on('end', () => {
        callback(null, reply);
      });
    }
  );

  req.on('error', (err) => {
    callback(err);
  });

  // Write data to request body
  req.write(bufObj);
  req.end();
}


const obj = {
  eventType: 20,
  eventSubType: 0,
  address: 1156774,
  subAddress: 0,
  userId: "7403",
  cardNo: "12345678",
  eventDetail: "whatever",
  linkedEventId: 0,
  ioBoardId: 0,
  inputId: 0,
  outputId: 0
};

async.eachSeries(
  EVENT_NRS,
  (val, cb) => {
    console.log(val);
    obj.eventType = val;
    obj.eventDetail = `Event ${val}`;
    sendEvent(obj, (err, reply) => {
      if (err) {
        cb(err);
      } else if (!reply) {
        cb(new Error('False reply'));
      } else {
        console.log('OK');
        cb();
      }
    });
  },
  (err) => {
    if (err) {
      console.log('Oops:', err);
    }
  }
);
